==> portal-transparencia-2.016.0.zip: BOOT-INF/classes/db/sql/contab/patrimonio_bem_baixa.sql <==
SELECT A.BAIXADO,
       A.DATABAIXA,
       CASE A.TIPO WHEN 'M' THEN (SELECT MB.JUSTIFICATIVA
                                    FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA MB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO MBAL
                                      ON MBAL.ALIENACAO = MB.ALIENACAO
                                   WHERE MB.ENTIDADE=A.ENTIDADE
                                     AND MB.TIPO=A.TIPO
                                     AND MB.BEM=A.BEM
                                     AND MB.CHAPA=A.CHAPA
                                     AND MB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))
                   WHEN 'I' THEN (SELECT IB.JUSTIFICATIVA
                                    FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA IB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO IBAL
                                      ON IBAL.ALIENACAO = IB.ALIENACAO
                                   WHERE IB.ENTIDADE=A.ENTIDADE
                                     AND IB.TIPO=A.TIPO
                                     AND IB.BEM=A.BEM
                                     AND IB.CHAPA=A.CHAPA
                                     AND IB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))
                   WHEN 'V' THEN (SELECT VB.JUSTIFICATIVA
                                    FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA VB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO VBAL ON VBAL.ALIENACAO = VB.ALIENACAO
                                   WHERE VB.ENTIDADE=A.ENTIDADE
                                     AND VB.TIPO=A.TIPO
                                     AND VB.BEM=A.BEM
                                     AND VB.CHAPA=A.CHAPA
                                     AND VB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))
       END AS JUSTIFICATIVA,
       CASE A.TIPO WHEN 'M' THEN (SELECT MBAL.DESCRICAO
                                    FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA MB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO MBAL
                                      ON MBAL.ALIENACAO = MB.ALIENACAO
                                   WHERE MB.ENTIDADE=A.ENTIDADE
                                     AND MB.TIPO=A.TIPO
                                     AND MB.BEM=A.BEM
                                     AND MB.CHAPA=A.CHAPA
                                     AND MB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))


                   WHEN 'I' THEN (SELECT IBAL.DESCRICAO
                                    FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA IB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO IBAL ON IBAL.ALIENACAO = IB.ALIENACAO
                                   WHERE IB.ENTIDADE=A.ENTIDADE
                                     AND IB.TIPO=A.TIPO
                                     AND IB.BEM=A.BEM
                                     AND IB.CHAPA=A.CHAPA
                                     AND IB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))

                   WHEN 'V' THEN (SELECT VBAL.DESCRICAO
                                    FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA VB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO VBAL ON VBAL.ALIENACAO = VB.ALIENACAO
                                   WHERE VB.ENTIDADE=A.ENTIDADE
                                     AND VB.TIPO=A.TIPO
                                     AND VB.BEM=A.BEM
                                     AND VB.CHAPA=A.CHAPA
                                     AND VB.CODIGO = (SELECT MAX(B.CODIGO)
                                                       FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA B
                                                      WHERE B.ENTIDADE=A.ENTIDADE
                                                        AND B.TIPO=A.TIPO
                                                        AND B.BEM=A.BEM
                                                        AND B.CHAPA=A.CHAPA))


           END AS TIPOBAIXA
  FROM ${db.contabilidade.schema}.PAT_BEM A
  $[FILTRO]

==> portal-transparencia-2.067.0.zip: BOOT-INF/classes/db/sql/contab/patrimonio_bem_baixa.sql <==
SELECT A.BAIXADO,
       A.DATABAIXA,
       CASE A.TIPO WHEN 'M' THEN (SELECT MB.JUSTIFICATIVA
                                    FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA MB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO MBAL
                                      ON MBAL.ALIENACAO = MB.ALIENACAO
                                   WHERE MB.ENTIDADE=A.ENTIDADE
                                     AND MB.TIPO=A.TIPO
                                     AND MB.BEM=A.BEM
                                     AND MB.CHAPA=A.CHAPA
                                     AND MB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))
                   WHEN 'I' THEN (SELECT IB.JUSTIFICATIVA
                                    FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA IB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO IBAL
                                      ON IBAL.ALIENACAO = IB.ALIENACAO
                                   WHERE IB.ENTIDADE=A.ENTIDADE
                                     AND IB.TIPO=A.TIPO
                                     AND IB.BEM=A.BEM
                                     AND IB.CHAPA=A.CHAPA
                                     AND IB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))
                   WHEN 'V' THEN (SELECT VB.JUSTIFICATIVA
                                    FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA VB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO VBAL ON VBAL.ALIENACAO = VB.ALIENACAO
                                   WHERE VB.ENTIDADE=A.ENTIDADE
                                     AND VB.TIPO=A.TIPO
                                     AND VB.BEM=A.BEM
                                     AND VB.CHAPA=A.CHAPA
                                     AND VB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))
       END AS JUSTIFICATIVA,
       CASE A.TIPO WHEN 'M' THEN (SELECT MBAL.DESCRICAO
                                    FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA MB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO MBAL
                                      ON MBAL.ALIENACAO = MB.ALIENACAO
                                   WHERE MB.ENTIDADE=A.ENTIDADE
                                     AND MB.TIPO=A.TIPO
                                     AND MB.BEM=A.BEM
                                     AND MB.CHAPA=A.CHAPA
                                     AND MB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))


                   WHEN 'I' THEN (SELECT IBAL.DESCRICAO
                                    FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA IB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO IBAL ON IBAL.ALIENACAO = IB.ALIENACAO
                                   WHERE IB.ENTIDADE=A.ENTIDADE
                                     AND IB.TIPO=A.TIPO
                                     AND IB.BEM=A.BEM
                                     AND IB.CHAPA=A.CHAPA
                                     AND IB.CODIGO = (SELECT MAX(B.CODIGO)
                                                        FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA B
                                                       WHERE B.ENTIDADE=A.ENTIDADE
                                                         AND B.TIPO=A.TIPO
                                                         AND B.BEM=A.BEM
                                                         AND B.CHAPA=A.CHAPA))

                   WHEN 'V' THEN (SELECT VBAL.DESCRICAO
                                    FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA VB
                                    LEFT JOIN ${db.contabilidade.schema}.PAT_ALIENACAO VBAL ON VBAL.ALIENACAO = VB.ALIENACAO
                                   WHERE VB.ENTIDADE=A.ENTIDADE
                                     AND VB.TIPO=A.TIPO
                                     AND VB.BEM=A.BEM
                                     AND VB.CHAPA=A.CHAPA
                                     AND VB.CODIGO = (SELECT MAX(B.CODIGO)
                                                       FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA B
                                                      WHERE B.ENTIDADE=A.ENTIDADE
                                                        AND B.TIPO=A.TIPO
                                                        AND B.BEM=A.BEM
                                                        AND B.CHAPA=A.CHAPA))


           END AS TIPOBAIXA,

           CASE A.TIPO WHEN 'M' THEN (SELECT F.NOME
                                               FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA MB
                                               LEFT JOIN ${db.contabilidade.schema}.FORNECEDOR F
                                                 ON F.FORNECEDOR = MB.FORNECEDOR
                                              WHERE MB.ENTIDADE=A.ENTIDADE
                                                AND MB.TIPO=A.TIPO
                                                AND MB.BEM=A.BEM
                                                AND MB.CHAPA=A.CHAPA
                                                AND MB.CODIGO = (SELECT MAX(B.CODIGO)
                                                                   FROM ${db.contabilidade.schema}.PAT_BEMMOVELBAIXA B
                                                                  WHERE B.ENTIDADE=A.ENTIDADE
                                                                    AND B.TIPO=A.TIPO
                                                                    AND B.BEM=A.BEM
                                                                    AND B.CHAPA=A.CHAPA))


                              WHEN 'I' THEN (SELECT F.NOME
                                               FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA IB
                                                   LEFT JOIN ${db.contabilidade.schema}.FORNECEDOR F
                                                                                                ON F.FORNECEDOR = IB.FORNECEDOR
                                              WHERE IB.ENTIDADE=A.ENTIDADE
                                                AND IB.TIPO=A.TIPO
                                                AND IB.BEM=A.BEM
                                                AND IB.CHAPA=A.CHAPA
                                                AND IB.CODIGO = (SELECT MAX(B.CODIGO)
                                                                   FROM ${db.contabilidade.schema}.PAT_BEMIMOVELBAIXA B
                                                                  WHERE B.ENTIDADE=A.ENTIDADE
                                                                    AND B.TIPO=A.TIPO
                                                                    AND B.BEM=A.BEM
                                                                    AND B.CHAPA=A.CHAPA))

                              WHEN 'V' THEN (SELECT F.NOME
                                               FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA VB
                                                   LEFT JOIN ${db.contabilidade.schema}.FORNECEDOR F
                                                                                                ON F.FORNECEDOR = VB.FORNECEDOR
                                              WHERE VB.ENTIDADE=A.ENTIDADE
                                                AND VB.TIPO=A.TIPO
                                                AND VB.BEM=A.BEM
                                                AND VB.CHAPA=A.CHAPA
                                                AND VB.CODIGO = (SELECT MAX(B.CODIGO)
                                                                  FROM ${db.contabilidade.schema}.PAT_BEMVEICULOBAIXA B
                                                                 WHERE B.ENTIDADE=A.ENTIDADE
                                                                   AND B.TIPO=A.TIPO
                                                                   AND B.BEM=A.BEM
                                                                   AND B.CHAPA=A.CHAPA))


                      END AS NOMECOMPRADOR
  FROM ${db.contabilidade.schema}.PAT_BEM A
  $[FILTRO]
